@@ -29,7 +29,7 @@ def run_cmd(cmd: list[str]):
 
 
 def raise_error(txt: str):
-    typer.echo(typer.style("Error: " + str(txt), fg="red"), err=txt)
+    typer.echo(typer.style("Error: " + str(txt), fg="red"), err=True)
     raise typer.Exit(1)
 
 
